@@ -343,7 +343,8 @@ setClass("EstimationTask",
          slots=c(metrics='character',        # the metrics to be estimated
                  method="EstimationMethod",  # the estimation method to use
                  evaluator='character',      # function used to calculate the metrics
-                 evaluator.pars='OptList'    # pars to this function
+                 evaluator.pars='OptList',   # pars to this function
+                 trainReq='logical'          # is the training data required?
          )
          )
 
@@ -351,10 +352,12 @@ setClass("EstimationTask",
 ## constructor
 ##
 EstimationTask <- function(metrics,method=CV(),
-                           evaluator="",evaluator.pars=NULL) {
+                           evaluator="",evaluator.pars=NULL,
+                           trainReq=FALSE) {
     new("EstimationTask",
         metrics=metrics,method=method,
-        evaluator=evaluator,evaluator.pars=evaluator.pars)
+        evaluator=evaluator,evaluator.pars=evaluator.pars,
+        trainReq=trainReq)
 }
 
 
